# Strawberry docs

- [Getting started](./index.md)

## General

- [Schema basics](./general/schema-basics.md)
- [Queries](./general/queries.md)
- [Mutations](./general/mutations.md)
- [Subscriptions](./general/subscriptions.md)
- [Why](./general/why.md)
- [Breaking changes](./breaking-changes.md)

## Types

- [Schema](./types/schema.md)
- [Schema Directives](./types/schema-directives.md)
- [Schema configurations](./types/schema-configurations.md)
- [Scalars](./types/scalars.md)
- [Object types](./types/object-types.md)
- [Interfaces](./types/interfaces.md)
- [Input types](./types/input-types.md)
- [Enums](./types/enums.md)
- [Generics](./types/generics.md)
- [Resolvers](./types/resolvers.md)
- [Union types](./types/union.md)
- [Lazy types](./types/lazy.md)
- [Exceptions](./types/exceptions.md)
- [Private/External Fields](./types/private.md)

## Codegen

- [Query codegen](./codegen/query-codegen.md)

## [Extensions](./extensions)

## Guides

- [Authentication](./guides/authentication.md)
- [DataLoaders](./guides/dataloaders.md)
- [Dealing with errors](./guides/errors.md)
- [Federation](./guides/federation.md)
- [Federation V1](./guides/federation-v1.md)
- [Custom extensions](./guides/custom-extensions.md)
- [File upload](./guides/file-upload.md)
- [Pagination](./guides/pagination.md)
- [Permissions](./guides/permissions.md)
- [Builtin server](./guides/server.md)
- [Tools](./guides/tools.md)
- [Schema export](./guides/schema-export.md)

## Editor integration

- [Mypy](./editors/mypy.md)
- [Visual Studio Code](./editors/vscode.md)

## Concepts

- [Async](./concepts/async.md)
- [Type hints](./concepts/typings.md)

## Integrations

- [AIOHTTP](./integrations/aiohttp.md)
- [ASGI](./integrations/asgi.md)
- [Django](./integrations/django.md)
- [Channels](./integrations/channels.md)
- [FastAPI](./integrations/fastapi.md)
- [Flask](./integrations/flask.md)
- [Sanic](./integrations/sanic.md)
- [Chalice](./integrations/chalice.md)
- [Starlette](./integrations/starlette.md)
- [Pydantic **experimental**](./integrations/pydantic.md)

## Operations

- [Deployment](./operations/deployment.md)
- [Testing](./operations/testing.md)
- [Tracing](./operations/tracing.md)
